#!/usr/bin/perl -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/shell
# $Id: user_shell.pl
#
# toggle shell access on or off for user
#

use CCE;
use Base::User qw(usermod);
use MyShell;

# Debugging switch:
$DEBUG = "0";
if ($DEBUG) {
    use Sys::Syslog qw( :DEFAULT setlogsock);
    use Data::Dumper;
}

my $cce = new CCE;
$cce->connectfd();

&debug_msg("Available: $MyShell::BAD_SHELL $MyShell::GOOD_SHELL $MyShell::SUSPEND_SHELL\n");

my $user = $cce->event_object();
my ($ok, $shell, $shell_old, $shell_new) = $cce->get($cce->event_oid(), 'Shell');
if (!$ok)
{
    $cce->bye('FAIL', '[[base-shell.cantReadUserShell]]');
    exit(1);
}

&debug_msg("shell: $shell - shell_old: $shell_old - shell_new: $shell_new\n");

# run on create, so make sure we have the info needed
if ($cce->event_is_create() && !scalar(getpwnam($user->{name})))
{
    $cce->bye('DEFER');
    exit(0);
}

# if they have a site defined, verify that site is allowed shell access
# and isn't suspended
my $vsite_shell = {};
if ($user->{site})
{
    my ($site_oid) = $cce->find('Vsite', { 'name' => $user->{site} });
    ($ok, $vsite_shell) = $cce->get($site_oid, 'Shell');

    if (!$ok)
    {
        $cce->bye('FAIL', '[[base-shell.cceError]]');
        exit(1);
    }

    # only worry if they are trying to toggle from off to on for user
    # shell
    if ($shell_new->{enabled} && !$vsite_shell->{enabled})
    {
        $cce->bye('FAIL', '[[base-shell.cantEnableNoVsiteShell]]');
        exit(1);
    }
}

# if the user is suspended or shell is turned off, set shell to non-bash
my $fail_msg = '';
my $new_shell = $MyShell::BAD_SHELL;
if (!$user->{enabled} || !$shell->{enabled} || (exists($vsite_shell->{enabled}) && !$vsite_shell->{enabled})) {
    $fail_msg = '[[base-shell.cantDisableUserShell]]';
    $new_shell = (!$user->{enabled} ? $MyShell::SUSPEND_SHELL : $MyShell::BAD_SHELL);
}
elsif ($shell->{enabled})
{
    $fail_msg = '[[base-shell.cantEnableUserShell]]';
    $new_shell = $MyShell::GOOD_SHELL;
}

&debug_msg("new shell is $new_shell\n");
my $changeUser = { 'name' => $user->{name}, 'shell' => $new_shell };
my ($success, $bad_users, $err, $errmsg) = usermod($changeUser);
&debug_msg("Result: $success - $err - $errmsg");

if ($success != 0) {
    &debug_msg("Failed usermod reported in user_shell.pl\n");
    $cce->bye('FAIL', $errmsg);
    exit(1);
}
else {
    &debug_msg("Successful usermod ...\n");
}

$cce->bye('SUCCESS');
exit(0);

#
### Subroutines:
#

sub debug_msg {
    if ($DEBUG) {
        my $msg = shift;
        setlogsock('unix');
        openlog($0,'','user');
        syslog('info', "$ARGV[0]: $msg");
        closelog;
    }
}

# 
# Copyright (c) 2008-2019 Michael Stauber, SOLARSPEED.NET
# Copyright (c) 2008-2019 Team BlueOnyx, BLUEONYX.IT
# Copyright (c) 2003 Sun Microsystems, Inc. 
# All Rights Reserved.
# 
# 1. Redistributions of source code must retain the above copyright 
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright 
#    notice, this list of conditions and the following disclaimer in 
#    the documentation and/or other materials provided with the 
#    distribution.
# 
# 3. Neither the name of the copyright holder nor the names of its 
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
# 
# You acknowledge that this software is not designed or intended for 
# use in the design, construction, operation or maintenance of any 
# nuclear facility.
# 