#!/usr/bin/perl -w -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/shell
# $Id: vsite_shell.pl
#
# toggle shell access on and off for all site users when the vsite
#

# Debugging switch:
$DEBUG = "0";
if ($DEBUG) {
    use Sys::Syslog qw( :DEFAULT setlogsock);
    use Data::Dumper;
}

use CCE;
use Base::User qw(usermod);
use MyShell;
use Base::Vsite qw(vsite_update_site_admin_caps);

my $cce = new CCE;
$cce->connectfd();

my $vsite = $cce->event_object();
my ($ok, $shell) = $cce->get($cce->event_oid(), 'Shell');
if (!$ok)
{
    $cce->bye('FAIL', '[[base-shell.cantReadVsiteShell]]');
    exit(1);
}

# if the vsite is suspended or shell is turned off, disable shell for
# all users
my @usermods = ();
my $fail_msg = '';
if ($vsite->{suspend} || !$shell->{enabled})
{
    &debug_msg("Case: suspend || shell not enabled");
    $fail_msg = '[[base-shell.cantDisableVsiteShell]]';
    my $new_shell = ($vsite->{suspend} ? $MyShell::SUSPEND_SHELL : $MyShell::BAD_SHELL);

    # don't toggle the User.Shell.enabled property, because it should
    # be restored if the site is given shell access again
    my @users = $cce->find('User', { 'site' => $vsite->{name} });
    for my $oid (@users)
    {
        ($ok, my $user) = $cce->get($oid);
        if (!$ok)
        {
            $cce->bye('FAIL', '[[base-shell.cantReadVsiteUser]]');
            exit(1);
        }
        my $changeUser = { 'name' => $user->{name}, 'shell' => $new_shell };
        my ($success, $bad_users, $err, $errmsg) = usermod($changeUser);
        &debug_msg("Result: $success - $err - $errmsg");
        if ($success != 0) {
            &debug_msg("Failed usermod reported in user_shell.pl\n");
            $cce->bye('FAIL', $errmsg);
            exit(1);
        }        
    } # got all users
}
elsif ($shell->{enabled})
{

    &debug_msg("Case: shell was enabled");

    $fail_msg = '[[base-shell.cantEnableVsiteShell]]';
    # enable shell for all users, who have been given shell access
    my @users = $cce->find('User', { 'site' => $vsite->{name} });
    for my $oid (@users)
    {
        ($ok, my $user) = $cce->get($oid);
        ($ok, my $user_shell) = $cce->get($oid, 'Shell');
        if (!$ok)
        {
            $cce->bye('FAIL', '[[base-shell.cantReadVsiteUser]]');
            exit(1);
        }
        
        my $new_shell = $MyShell::BAD_SHELL;
        if ($user_shell->{enabled})
        {
            $new_shell = $MyShell::GOOD_SHELL;
        }

        my $changeUser = { 'name' => $user->{name}, 'shell' => $new_shell };
        my ($success, $bad_users, $err, $errmsg) = usermod($changeUser);
        &debug_msg("Result: $success - $err - $errmsg");
        if ($success != 0) {
            &debug_msg("Failed usermod reported in user_shell.pl\n");
            $cce->bye('FAIL', $errmsg);
            exit(1);
        }
    } # got all site users
}

# update site admin caps
if (!$cce->event_is_destroy()){
    vsite_update_site_admin_caps($cce, $vsite, 'siteShell', $shell->{enabled});
}

#
### Subroutines:
#

sub debug_msg {
    if ($DEBUG) {
        my $msg = shift;
        setlogsock('unix');
        openlog($0,'','user');
        syslog('info', "$ARGV[0]: $msg");
        closelog;
    }
}


$cce->bye('SUCCESS');
exit(0);

# 
# Copyright (c) 2008-2019 Michael Stauber, SOLARSPEED.NET
# Copyright (c) 2008-2019 Team BlueOnyx, BLUEONYX.IT
# Copyright (c) 2003 Sun Microsystems, Inc. 
# All Rights Reserved.
# 
# 1. Redistributions of source code must retain the above copyright 
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright 
#    notice, this list of conditions and the following disclaimer in 
#    the documentation and/or other materials provided with the 
#    distribution.
# 
# 3. Neither the name of the copyright holder nor the names of its 
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
# 
# You acknowledge that this software is not designed or intended for 
# use in the design, construction, operation or maintenance of any 
# nuclear facility.
# 